summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--byterun/Makefile.Mac7
-rw-r--r--byterun/Makefile.Mac.depend182
-rw-r--r--byterun/signals.c2
-rw-r--r--config/config.Mac14
-rw-r--r--maccaml/Makefile.Mac3
-rw-r--r--maccaml/Makefile.Mac.depend4
-rw-r--r--maccaml/events.c10
-rw-r--r--maccaml/glue.c32
-rw-r--r--maccaml/graph.c12
-rw-r--r--maccaml/gusistuff.cp14
-rw-r--r--maccaml/main.c5
-rw-r--r--maccaml/main.h5
-rw-r--r--maccaml/menus.c3
-rw-r--r--otherlibs/bigarray/Makefile.Mac6
-rw-r--r--otherlibs/bigarray/Makefile.Mac.depend4
-rw-r--r--otherlibs/macosunix/Makefile.Mac3
-rw-r--r--otherlibs/macosunix/Makefile.Mac.depend4
-rw-r--r--otherlibs/num/Makefile.Mac6
-rw-r--r--otherlibs/num/Makefile.Mac.depend4
-rw-r--r--otherlibs/num/bignum/Makefile.Mac8
-rw-r--r--otherlibs/str/Makefile.Mac6
-rw-r--r--otherlibs/str/Makefile.Mac.depend4
-rw-r--r--otherlibs/str/regex-0.12/Makefile.Mac4
-rw-r--r--otherlibs/systhreads/Makefile.Mac3
-rw-r--r--otherlibs/systhreads/Makefile.Mac.depend4
-rw-r--r--test/Moretest/graph_example.ml2
-rw-r--r--tools/Makefile.Mac.depend6
-rw-r--r--utils/config.mlp2
-rw-r--r--yacc/.cvsignore1
-rw-r--r--yacc/Makefile.Mac6
-rw-r--r--yacc/closure.c2
31 files changed, 206 insertions, 162 deletions
diff --git a/byterun/Makefile.Mac b/byterun/Makefile.Mac
index a66172b39..2c3b453c4 100644
--- a/byterun/Makefile.Mac
+++ b/byterun/Makefile.Mac
@@ -12,10 +12,6 @@
# $Id$
-#adbgflag = -sym on -d DEBUG -wb -l
-#cdbgflag = -sym on -d DEBUG
-#ldbgflag = -sym on
-
C = sc
COptions = -w 29,30,35 {ocamlgusiflag} -i ::config: {cdbgflag}
-model far -mbg full
@@ -138,6 +134,9 @@ primitives {PRIMS}
-e "1,$ replace /([A-Z][A-Z_0-9]*)0/ '"' 0 '"' -c "
instruct.h > opnames.h
+:md5.c.x
+ {PPCC} :md5.c -o :md5.c.x -opt off {PPCCOptions} -opt off
+
:rotatecursor.c.o
{C} -b rotatecursor.c -o rotatecursor.c.o {COptions}
diff --git a/byterun/Makefile.Mac.depend b/byterun/Makefile.Mac.depend
index 7049bf607..98c868dda 100644
--- a/byterun/Makefile.Mac.depend
+++ b/byterun/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:49:05 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:16:18 on 7 avr 2000 by MakeDepend
:alloc.c.x
:alloc.c
@@ -836,7 +836,6 @@
:signals.h
:sys.h
:rotatecursor.h
- "{CIncludes}"windows.h
::config:m.h
::config:s.h
"{CIncludes}"setjmp.h
@@ -845,41 +844,10 @@
:minor_gc.h
"{CIncludes}"stddef.h
"{CIncludes}"stdlib.h
- "{CIncludes}"ConditionalMacros.h
- "{CIncludes}"MacWindows.h
:freelist.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
- "{CIncludes}"WCharTDef.h
- "{CIncludes}"MacTypes.h
- "{CIncludes}"Aliases.h
- "{CIncludes}"AppleEvents.h
- "{CIncludes}"Collections.h
- "{CIncludes}"Drag.h
- "{CIncludes}"Events.h
- "{CIncludes}"Menus.h
- "{CIncludes}"MixedMode.h
- "{CIncludes}"QDOffscreen.h
- "{CIncludes}"QuickDraw.h
- "{CIncludes}"TextCommon.h
- "{CIncludes}"Icons.h
- "{CIncludes}"MacErrors.h
- "{CIncludes}"AppleTalk.h
- "{CIncludes}"Files.h
- "{CIncludes}"Notification.h
- "{CIncludes}"AEDataModel.h
- "{CIncludes}"OSUtils.h
- "{CIncludes}"Endian.h
- "{CIncludes}"Fonts.h
- "{CIncludes}"Processes.h
- "{CIncludes}"Components.h
- "{CIncludes}"QuickdrawText.h
- "{CIncludes}"CodeFragments.h
- "{CIncludes}"UTCUtils.h
- "{CIncludes}"Finder.h
- "{CIncludes}"MacMemory.h
- "{CIncludes}"Patches.h
- "{CIncludes}"DateTimeUtils.h
+ "{CIncludes}"WCharTDef.h
:stacks.c.x
:stacks.c
@@ -910,6 +878,7 @@
"{CIncludes}"string.h
"{CIncludes}"fcntl.h
:config.h
+ "{CIncludes}"windows.h
:alloc.h
:callback.h
:custom.h
@@ -930,7 +899,6 @@
:signals.h
:stacks.h
:sys.h
- "{CIncludes}"windows.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"SeekDefs.h
@@ -938,13 +906,12 @@
"{CIncludes}"WCharTDef.h
::config:m.h
::config:s.h
+ "{CIncludes}"ConditionalMacros.h
+ "{CIncludes}"MacWindows.h
"{CIncludes}"setjmp.h
:gc.h
:major_gc.h
"{CIncludes}"stddef.h
- "{CIncludes}"ConditionalMacros.h
- "{CIncludes}"MacWindows.h
- :freelist.h
"{CIncludes}"MacTypes.h
"{CIncludes}"Aliases.h
"{CIncludes}"AppleEvents.h
@@ -958,6 +925,7 @@
"{CIncludes}"TextCommon.h
"{CIncludes}"Icons.h
"{CIncludes}"MacErrors.h
+ :freelist.h
"{CIncludes}"AppleTalk.h
"{CIncludes}"Files.h
"{CIncludes}"Notification.h
@@ -1014,7 +982,6 @@
:stacks.h
:sys.h
:ui.h
- "{CIncludes}"ctype.h
"{CIncludes}"SeekDefs.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"NullDef.h
@@ -1069,21 +1036,61 @@
"{CIncludes}"SizeTDef.h
"{CIncludes}"WCharTDef.h
-:wincmdline.c.x
- :wincmdline.c
+:win32.c.x
+ :win32.c
+ "{CIncludes}"windows.h
"{CIncludes}"stdlib.h
"{CIncludes}"stdio.h
"{CIncludes}"fcntl.h
"{CIncludes}"ctype.h
"{CIncludes}"string.h
+ "{CIncludes}"signal.h
+ :signals.h
+ "{CIncludes}"ConditionalMacros.h
+ "{CIncludes}"MacWindows.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"WCharTDef.h
"{CIncludes}"SeekDefs.h
- "{CIncludes}"VaListTDef.h
+ "{CIncludes}"VaListTDef.h
+ :misc.h
+ :mlvalues.h
+ "{CIncludes}"MacTypes.h
+ "{CIncludes}"Aliases.h
+ "{CIncludes}"AppleEvents.h
+ "{CIncludes}"Collections.h
+ "{CIncludes}"Drag.h
+ "{CIncludes}"Events.h
+ "{CIncludes}"Menus.h
+ "{CIncludes}"MixedMode.h
+ "{CIncludes}"QDOffscreen.h
+ "{CIncludes}"QuickDraw.h
+ "{CIncludes}"TextCommon.h
+ "{CIncludes}"Icons.h
+ "{CIncludes}"MacErrors.h
+ :config.h
+ "{CIncludes}"stddef.h
+ "{CIncludes}"AppleTalk.h
+ "{CIncludes}"Files.h
+ "{CIncludes}"Notification.h
+ "{CIncludes}"AEDataModel.h
+ "{CIncludes}"OSUtils.h
+ "{CIncludes}"Endian.h
+ "{CIncludes}"Fonts.h
+ "{CIncludes}"Processes.h
+ "{CIncludes}"Components.h
+ "{CIncludes}"QuickdrawText.h
+ "{CIncludes}"CodeFragments.h
+ ::config:m.h
+ ::config:s.h
+ "{CIncludes}"UTCUtils.h
+ "{CIncludes}"Finder.h
+ "{CIncludes}"MacMemory.h
+ "{CIncludes}"Patches.h
+ "{CIncludes}"DateTimeUtils.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:49:18 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:16:30 on 7 avr 2000 by MakeDepend
:alloc.c.o
:alloc.c
@@ -1920,7 +1927,6 @@
:signals.h
:sys.h
:rotatecursor.h
- "{CIncludes}"windows.h
::config:m.h
::config:s.h
"{CIncludes}"setjmp.h
@@ -1929,41 +1935,10 @@
:minor_gc.h
"{CIncludes}"stddef.h
"{CIncludes}"stdlib.h
- "{CIncludes}"ConditionalMacros.h
- "{CIncludes}"MacWindows.h
:freelist.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
- "{CIncludes}"WCharTDef.h
- "{CIncludes}"MacTypes.h
- "{CIncludes}"Aliases.h
- "{CIncludes}"AppleEvents.h
- "{CIncludes}"Collections.h
- "{CIncludes}"Drag.h
- "{CIncludes}"Events.h
- "{CIncludes}"Menus.h
- "{CIncludes}"MixedMode.h
- "{CIncludes}"QDOffscreen.h
- "{CIncludes}"QuickDraw.h
- "{CIncludes}"TextCommon.h
- "{CIncludes}"Icons.h
- "{CIncludes}"MacErrors.h
- "{CIncludes}"AppleTalk.h
- "{CIncludes}"Files.h
- "{CIncludes}"Notification.h
- "{CIncludes}"AEDataModel.h
- "{CIncludes}"OSUtils.h
- "{CIncludes}"Endian.h
- "{CIncludes}"Fonts.h
- "{CIncludes}"Processes.h
- "{CIncludes}"Components.h
- "{CIncludes}"QuickdrawText.h
- "{CIncludes}"CodeFragments.h
- "{CIncludes}"UTCUtils.h
- "{CIncludes}"Finder.h
- "{CIncludes}"MacMemory.h
- "{CIncludes}"Patches.h
- "{CIncludes}"DateTimeUtils.h
+ "{CIncludes}"WCharTDef.h
:stacks.c.o
:stacks.c
@@ -1994,6 +1969,7 @@
"{CIncludes}"string.h
"{CIncludes}"fcntl.h
:config.h
+ "{CIncludes}"windows.h
:alloc.h
:callback.h
:custom.h
@@ -2014,7 +1990,6 @@
:signals.h
:stacks.h
:sys.h
- "{CIncludes}"windows.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"SeekDefs.h
@@ -2022,13 +1997,12 @@
"{CIncludes}"WCharTDef.h
::config:m.h
::config:s.h
+ "{CIncludes}"ConditionalMacros.h
+ "{CIncludes}"MacWindows.h
"{CIncludes}"setjmp.h
:gc.h
:major_gc.h
"{CIncludes}"stddef.h
- "{CIncludes}"ConditionalMacros.h
- "{CIncludes}"MacWindows.h
- :freelist.h
"{CIncludes}"MacTypes.h
"{CIncludes}"Aliases.h
"{CIncludes}"AppleEvents.h
@@ -2042,6 +2016,7 @@
"{CIncludes}"TextCommon.h
"{CIncludes}"Icons.h
"{CIncludes}"MacErrors.h
+ :freelist.h
"{CIncludes}"AppleTalk.h
"{CIncludes}"Files.h
"{CIncludes}"Notification.h
@@ -2098,7 +2073,6 @@
:stacks.h
:sys.h
:ui.h
- "{CIncludes}"ctype.h
"{CIncludes}"SeekDefs.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"NullDef.h
@@ -2153,16 +2127,56 @@
"{CIncludes}"SizeTDef.h
"{CIncludes}"WCharTDef.h
-:wincmdline.c.o
- :wincmdline.c
+:win32.c.o
+ :win32.c
+ "{CIncludes}"windows.h
"{CIncludes}"stdlib.h
"{CIncludes}"stdio.h
"{CIncludes}"fcntl.h
"{CIncludes}"ctype.h
"{CIncludes}"string.h
+ "{CIncludes}"signal.h
+ :signals.h
+ "{CIncludes}"ConditionalMacros.h
+ "{CIncludes}"MacWindows.h
"{CIncludes}"NullDef.h
"{CIncludes}"SizeTDef.h
"{CIncludes}"WCharTDef.h
"{CIncludes}"SeekDefs.h
- "{CIncludes}"VaListTDef.h
+ "{CIncludes}"VaListTDef.h
+ :misc.h
+ :mlvalues.h
+ "{CIncludes}"MacTypes.h
+ "{CIncludes}"Aliases.h
+ "{CIncludes}"AppleEvents.h
+ "{CIncludes}"Collections.h
+ "{CIncludes}"Drag.h
+ "{CIncludes}"Events.h
+ "{CIncludes}"Menus.h
+ "{CIncludes}"MixedMode.h
+ "{CIncludes}"QDOffscreen.h
+ "{CIncludes}"QuickDraw.h
+ "{CIncludes}"TextCommon.h
+ "{CIncludes}"Icons.h
+ "{CIncludes}"MacErrors.h
+ :config.h
+ "{CIncludes}"stddef.h
+ "{CIncludes}"AppleTalk.h
+ "{CIncludes}"Files.h
+ "{CIncludes}"Notification.h
+ "{CIncludes}"AEDataModel.h
+ "{CIncludes}"OSUtils.h
+ "{CIncludes}"Endian.h
+ "{CIncludes}"Fonts.h
+ "{CIncludes}"Processes.h
+ "{CIncludes}"Components.h
+ "{CIncludes}"QuickdrawText.h
+ "{CIncludes}"CodeFragments.h
+ ::config:m.h
+ ::config:s.h
+ "{CIncludes}"UTCUtils.h
+ "{CIncludes}"Finder.h
+ "{CIncludes}"MacMemory.h
+ "{CIncludes}"Patches.h
+ "{CIncludes}"DateTimeUtils.h
diff --git a/byterun/signals.c b/byterun/signals.c
index de8dda942..eb50f0470 100644
--- a/byterun/signals.c
+++ b/byterun/signals.c
@@ -129,8 +129,8 @@ void leave_blocking_section(void)
if (leave_blocking_section_hook != NULL) leave_blocking_section_hook();
#if !macintosh_GUSI
Assert(async_signal_mode);
- async_signal_mode = 0;
#endif
+ async_signal_mode = 0;
}
#ifndef SIGABRT
diff --git a/config/config.Mac b/config/config.Mac
index 5d2d8a810..ab2530401 100644
--- a/config/config.Mac
+++ b/config/config.Mac
@@ -33,7 +33,7 @@ set -e APPLIDIR "{mpw}:OCaml-distrib:"
### Which libraries to compile and install
# Currently available:
-# bigarray
+# bigarray Statically-allocated arrays
# dynlink Dynamic linking of bytecode
# graph Graphics (for the standalone application only)
# macosunix Unix emulation (application only)
@@ -47,6 +47,18 @@ set -e APPLIDIR "{mpw}:OCaml-distrib:"
set -e OTHERLIBRARIES "bigarray dynlink graph macosunix num str systhreads"
+############# To compile in debug mode (or not)
+
+# compile without debugging info / with optimisations
+unset adbgflag ldbgflag
+set -e cdbgflag "-d NDEBUG"
+
+# compile with debugging info / without optimisations
+#set -e adbgflag "-sym on -d DEBUG -wb -l"
+#set -e cdbgflag "-sym on -d DEBUG"
+#set -e ldbgflag "-sym on"
+
+
############# Configuration for the native-code compiler
# (not used for the moment)
diff --git a/maccaml/Makefile.Mac b/maccaml/Makefile.Mac
index c78c31d0d..6b560d82e 100644
--- a/maccaml/Makefile.Mac
+++ b/maccaml/Makefile.Mac
@@ -12,9 +12,6 @@
# $Id$
-#cdbgflag = -sym on -d DEBUG
-#ldbgflag = -sym on
-
VERSIONSTR =
""{OCAMLMAJOR}.{OCAMLMINOR}/Mac{MAJOR}.{MINOR}.{BUGFIX}{STAGE}{REV}""
COPYRIGHTSTR = ""Copyright 1991-2000 INRIA""
diff --git a/maccaml/Makefile.Mac.depend b/maccaml/Makefile.Mac.depend
index 61f36b8d5..54b7b74ee 100644
--- a/maccaml/Makefile.Mac.depend
+++ b/maccaml/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:51:03 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:55 on 7 avr 2000 by MakeDepend
:aboutbox.c.x
:aboutbox.c
@@ -1671,7 +1671,7 @@
"{CIncludes}"DriverSynchronization.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:51:12 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:18:04 on 7 avr 2000 by MakeDepend
:aboutbox.c.o
:aboutbox.c
diff --git a/maccaml/events.c b/maccaml/events.c
index d60995734..8bef9b2b4 100644
--- a/maccaml/events.c
+++ b/maccaml/events.c
@@ -88,16 +88,10 @@ static void DoKeyDown (EventRecord *evt)
chr = -1;
}
}
- /* If we were called by GUSI via RotateCursor or the Spin hook,
- GUSI will raise SIGINT if command-period was pressed, so we
- do it only if in_gusi is false.
- */
if (isCmdKey && chr == '.'
&& FrontWindow () == winToplevel
- && evt->what != autoKey
- && !in_gusi){
+ && evt->what != autoKey){
intr_requested = 1;
- raise (SIGINT);
}
if (isCmdKey && chr >= 0x20){
UpdateMenus ();
@@ -293,8 +287,6 @@ void GetAndProcessEvents (WaitEventOption wait, short oldx, short oldy)
RgnHandle dummyregion;
UInt32 cursleep = (wait == noWait) ? 0 : evtSleep;
RgnHandle currgn;
-
- if (!in_gusi && quit_requested && !exit_called) exit (0);
if (wait == waitMove){
currgn = pointRegion;
diff --git a/maccaml/gusistuff.cp b/maccaml/gusistuff.cp
index e2330f26f..2d39c157b 100644
--- a/maccaml/gusistuff.cp
+++ b/maccaml/gusistuff.cp
@@ -12,6 +12,7 @@
/* $Id$ */
#define GUSI_SOURCE
+#include <GUSIConfig.h>
#include <GUSIBasics.h>
extern "C" {
@@ -29,6 +30,14 @@ extern "C" void InitialiseGUSI (void)
GUSISetHook (GUSI_SpinHook, (GUSIHook) spin_hook_for_gusi);
}
+void GUSIConfiguration::CheckInterrupt ()
+{
+ if (intr_requested){
+ intr_requested = 0;
+ raise (SIGINT);
+ }
+}
+
/**************** B E G I N GUSI CONFIGURATION ****************************
*
* GUSI Configuration section generated by GUSI Configurator
@@ -97,7 +106,9 @@ void GUSISetupDevices()
#endif
GUSIConfiguration::FileSuffix sSuffices[] = {
- "", '????', '????'
+ ".ml" , 'TEXT', 'Caml',
+ ".mli" , 'TEXT', 'Caml',
+ "" , '????', '????',
};
extern "C" void GUSISetupConfig()
@@ -110,6 +121,7 @@ extern "C" void GUSISetupConfig()
config->ConfigureAutoInitGraf(false);
config->ConfigureAutoSpin(false);
config->ConfigureSigPipe(true);
+ config->ConfigureSigInt(false);
}
/**************** E N D GUSI CONFIGURATION *************************/
diff --git a/maccaml/main.c b/maccaml/main.c
index cef02288d..9f545efd7 100644
--- a/maccaml/main.c
+++ b/maccaml/main.c
@@ -116,7 +116,10 @@ int main (void)
quit_requested = 1;
exit (0);
}
- while (!launch_toplevel_requested) GetAndProcessEvents (waitEvent, 0, 0);
+ while (!launch_toplevel_requested){
+ GetAndProcessEvents (waitEvent, 0, 0);
+ if (quit_requested) exit (0);
+ }
err = launch_caml_main ();
if (err != noErr) ErrorAlertGeneric (err);
exit (0);
diff --git a/maccaml/main.h b/maccaml/main.h
index 29d98b509..954e92d9e 100644
--- a/maccaml/main.h
+++ b/maccaml/main.h
@@ -108,6 +108,10 @@ struct prefs {
TextStyle errors;
};
+/* from ::byterun:signals.c */
+extern int async_signal_mode;
+extern void handle_signal (int);
+
/* aboutbox.c */
void OpenAboutBox (void);
void CloseAboutBox (WindowPtr w);
@@ -151,7 +155,6 @@ OSErr FileDoSave (WindowPtr w, int saveasflag);
extern int intr_requested;
extern int quit_requested;
extern int exit_called;
-extern int in_gusi;
extern int caml_at_work;
void Caml_working (int newstate);
OSErr launch_caml_main (void);
diff --git a/maccaml/menus.c b/maccaml/menus.c
index ab9ce77f3..e62fd03e3 100644
--- a/maccaml/menus.c
+++ b/maccaml/menus.c
@@ -42,9 +42,8 @@ OSErr DoQuit ()
if (err != noErr) return err;
}
done:
- if (winGraphics != NULL) WinCloseGraphics ();
- WinCloseToplevel ();
quit_requested = 1;
+ intr_requested = 1;
return noErr;
}
diff --git a/otherlibs/bigarray/Makefile.Mac b/otherlibs/bigarray/Makefile.Mac
index e132c07a5..768b89fdf 100644
--- a/otherlibs/bigarray/Makefile.Mac
+++ b/otherlibs/bigarray/Makefile.Mac
@@ -13,10 +13,10 @@
# $Id$
C = sc
-COptions = -model far -i :::byterun:,:::config: -w 35
+COptions = -model far -i :::byterun:,:::config: -w 35 {cdbgflag}
PPCC = mrc
-PPCCOptions = -i :::byterun:,:::config: -w 35
+PPCCOptions = -i :::byterun:,:::config: -w 35 {cdbgflag}
CAMLC = :::boot:ocamlrun :::ocamlc -I :::stdlib: -I ::unix:
@@ -28,7 +28,7 @@ CAML_OBJS = bigarray.cmo
all libbigarray.x libbigarray.o bigarray.cma
libbigarray.x {PPCC_OBJS}
- ppclink -xm library -o libbigarray.x {PPCC_OBJS}
+ ppclink {ldbgflag} -xm library -o libbigarray.x {PPCC_OBJS}
libbigarray.o {C_OBJS}
lib -o libbigarray.o {C_OBJS}
diff --git a/otherlibs/bigarray/Makefile.Mac.depend b/otherlibs/bigarray/Makefile.Mac.depend
index 506247105..65298c74b 100644
--- a/otherlibs/bigarray/Makefile.Mac.depend
+++ b/otherlibs/bigarray/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:49:43 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:16:55 on 7 avr 2000 by MakeDepend
:bigarray_stubs.c.x
:bigarray_stubs.c
@@ -36,7 +36,7 @@
"{CIncludes}"WCharTDef.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:49:44 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:16:57 on 7 avr 2000 by MakeDepend
:bigarray_stubs.c.o
:bigarray_stubs.c
diff --git a/otherlibs/macosunix/Makefile.Mac b/otherlibs/macosunix/Makefile.Mac
index dd54e5179..19114a94b 100644
--- a/otherlibs/macosunix/Makefile.Mac
+++ b/otherlibs/macosunix/Makefile.Mac
@@ -12,9 +12,6 @@
# $Id$
-#ldbgflag = -sym on
-#cdbgflag = -sym on -d DEBUG
-
includepath = ":config:,:byterun:,{GUSI}include:"
C = sc
diff --git a/otherlibs/macosunix/Makefile.Mac.depend b/otherlibs/macosunix/Makefile.Mac.depend
index d989b186b..874bb249e 100644
--- a/otherlibs/macosunix/Makefile.Mac.depend
+++ b/otherlibs/macosunix/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:15 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:10 on 7 avr 2000 by MakeDepend
:accept.c.x
:accept.c
@@ -433,7 +433,7 @@
"{CIncludes}"MixedMode.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:22 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:16 on 7 avr 2000 by MakeDepend
:accept.c.o
:accept.c
diff --git a/otherlibs/num/Makefile.Mac b/otherlibs/num/Makefile.Mac
index e4fe24d69..19c1e14cf 100644
--- a/otherlibs/num/Makefile.Mac
+++ b/otherlibs/num/Makefile.Mac
@@ -16,9 +16,9 @@
# Compilation options
C = sc
-COptions = -model far -i :bignum:h:,:::byterun:,:::config: -w 35
+COptions = -model far -i :bignum:h:,:::byterun:,:::config: -w 35 {cdbgflag}
PPCC = mrc
-PPCCOptions = -i :bignum:h:,:::byterun:,:::config: -w 35
+PPCCOptions = -i :bignum:h:,:::byterun:,:::config: -w 35 {cdbgflag}
CAMLC = :::boot:ocamlrun :::ocamlc -I :::stdlib: -w s
CAMLOPT = :::boot:ocamlrun :::ocamlopt: -I :::stdlib: -w s
@@ -40,7 +40,7 @@ libnums.o :bignum:libbignum.o {COBJS}
lib -o libnums.o :bignum:libbignum.o {COBJS}
libnums.x :bignum:libbignum.x {PPCCOBJS}
- ppclink -xm library -o libnums.x :bignum:libbignum.x {PPCCOBJS}
+ ppclink {ldbgflag} -xm library -o libnums.x :bignum:libbignum.x {PPCCOBJS}
:bignum:libbignum.x :bignum:libbignum.o
echo -n
diff --git a/otherlibs/num/Makefile.Mac.depend b/otherlibs/num/Makefile.Mac.depend
index 0ca3a6e5b..aaea25f97 100644
--- a/otherlibs/num/Makefile.Mac.depend
+++ b/otherlibs/num/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:27 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:23 on 7 avr 2000 by MakeDepend
:nat_stubs.c.x
:nat_stubs.c
@@ -11,7 +11,7 @@
"{CIncludes}"MixedMode.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:28 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:24 on 7 avr 2000 by MakeDepend
:nat_stubs.c.o
:nat_stubs.c
diff --git a/otherlibs/num/bignum/Makefile.Mac b/otherlibs/num/bignum/Makefile.Mac
index 2a5d80f28..3c477d881 100644
--- a/otherlibs/num/bignum/Makefile.Mac
+++ b/otherlibs/num/bignum/Makefile.Mac
@@ -1,15 +1,15 @@
# Copyright Digital Equipment Corporation & INRIA 1988, 1989, 1992
C = sc
-COptions = -model far -i :h: -d CAML_LIGHT -w 30
+COptions = -model far -i :h: -d CAML_LIGHT -w 30 {cdbgflag}
LinkOptions = -state nouse -compact -model far
Libs = "{libraries}IntEnv.far.o" "{libraries}MacRuntime.o"
"{clibraries}StdCLib.far.o" "{libraries}MathLib.far.o"
"{libraries}ToolLibs.o" "{libraries}Interface.o"
PPCC = mrc
-PPCCOptions = -i :h: -d CAML_LIGHT -w 30
-PPCLinkOptions =
+PPCCOptions = -i :h: -d CAML_LIGHT -w 30 {cdbgflag}
+PPCLinkOptions = {ldbgflag}
PPCLibs = "{sharedlibraries}MathLib" "{ppclibraries}PPCCRuntime.o"
"{ppclibraries}PPCToolLibs.o" "{sharedlibraries}StdCLib"
"{ppclibraries}StdCRuntime.o" "{sharedlibraries}InterfaceLib"
@@ -49,7 +49,7 @@ scratch
lib -o {LIB} {OBJECT}
{PPCLIB} {PPCOBJECT}
- ppclink -xm library -o {PPCLIB} {PPCOBJECT}
+ ppclink {ldbgflag} -xm library -o {PPCLIB} {PPCOBJECT}
# How to choose the machine dependent version. All produce KerN.o
:o:KerN.o :c:KerN.c
diff --git a/otherlibs/str/Makefile.Mac b/otherlibs/str/Makefile.Mac
index 0f910c604..aa6b96e7e 100644
--- a/otherlibs/str/Makefile.Mac
+++ b/otherlibs/str/Makefile.Mac
@@ -16,10 +16,10 @@
# Compilation options
C = sc
-COptions = -model far -i {REGEXLIB},:::byterun:,:::config: -w 7
+COptions = -model far -i {REGEXLIB},:::byterun:,:::config: -w 7 {cdbgflag}
PPCC = mrc
-PPCCOptions = -i {REGEXLIB},:::byterun:,:::config: -w 7
+PPCCOptions = -i {REGEXLIB},:::byterun:,:::config: -w 7 {cdbgflag}
CAMLC = :::boot:ocamlrun :::ocamlc -I :::stdlib:
REGEXLIB = :regex-0.12:
@@ -33,7 +33,7 @@ libstr.o {COBJS}
lib -o libstr.o {COBJS}
libstr.x {PPCCOBJS}
- ppclink -xm library -o libstr.x {PPCCOBJS}
+ ppclink {ldbgflag} -xm library -o libstr.x {PPCCOBJS}
str.cma str.cmo
{CAMLC} -a -o str.cma str.cmo
diff --git a/otherlibs/str/Makefile.Mac.depend b/otherlibs/str/Makefile.Mac.depend
index 34b37e985..1f6c5657d 100644
--- a/otherlibs/str/Makefile.Mac.depend
+++ b/otherlibs/str/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:33 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:29 on 7 avr 2000 by MakeDepend
:strstubs.c.x
:strstubs.c
@@ -13,7 +13,7 @@
"{CIncludes}"MixedMode.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:35 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:31 on 7 avr 2000 by MakeDepend
:strstubs.c.o
:strstubs.c
diff --git a/otherlibs/str/regex-0.12/Makefile.Mac b/otherlibs/str/regex-0.12/Makefile.Mac
index f24949d14..dab5ab111 100644
--- a/otherlibs/str/regex-0.12/Makefile.Mac
+++ b/otherlibs/str/regex-0.12/Makefile.Mac
@@ -28,10 +28,10 @@ version = 0.12
CPPFLAGS =
C = sc
-COptions = -model far -w 29,35
+COptions = -model far -w 29,35 {cdbgflag}
PPCC = mrc
-PPCCOptions = -w 29,35
+PPCCOptions = -w 29,35 {cdbgflag}
DEFS = -d STDC_HEADERS -d STRING_H -d REGEX_MALLOC
diff --git a/otherlibs/systhreads/Makefile.Mac b/otherlibs/systhreads/Makefile.Mac
index 07891638e..4a84900aa 100644
--- a/otherlibs/systhreads/Makefile.Mac
+++ b/otherlibs/systhreads/Makefile.Mac
@@ -12,9 +12,6 @@
# $Id$
-#cdbgflag = -sym on -d DEBUG
-#ldbgflag = -sym on
-
C = sc
COptions = -includes unix -i ":::byterun:,:::config:,{GUSI}include:" -w 35
{cdbgflag} -model far
diff --git a/otherlibs/systhreads/Makefile.Mac.depend b/otherlibs/systhreads/Makefile.Mac.depend
index 1c466e91a..b61c20db9 100644
--- a/otherlibs/systhreads/Makefile.Mac.depend
+++ b/otherlibs/systhreads/Makefile.Mac.depend
@@ -1,5 +1,5 @@
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:42 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:38 on 7 avr 2000 by MakeDepend
:posix.c.x
:posix.c
@@ -52,7 +52,7 @@
"{CIncludes}"DateTimeUtils.h
#*** Dependencies: Cut here ***
-# These dependencies were produced at 14:50:47 on 3 avr 2000 by MakeDepend
+# These dependencies were produced at 17:17:43 on 7 avr 2000 by MakeDepend
:posix.c.o
:posix.c
diff --git a/test/Moretest/graph_example.ml b/test/Moretest/graph_example.ml
index dfb923f7b..9ddf971b6 100644
--- a/test/Moretest/graph_example.ml
+++ b/test/Moretest/graph_example.ml
@@ -27,7 +27,7 @@ let point x y =
else if dg > db then set_color (rgb (255*dr/dg) 255 (255*db/dg))
else set_color (rgb (255*dr/db) (255*dg/db) 255);
fill_rect x y 2 2;
-;;
+;;
for y = (size_y () - 1) / 2 downto 0 do
for x = 0 to (size_x () - 1) / 2 do
diff --git a/tools/Makefile.Mac.depend b/tools/Makefile.Mac.depend
index 39ced0b9e..fbdc39f71 100644
--- a/tools/Makefile.Mac.depend
+++ b/tools/Makefile.Mac.depend
@@ -4,10 +4,12 @@ dumpapprox.cmx ::asmcomp:clambda.cmx ::asmcomp:compilenv.cmx
::utils:config.cmx
dumpobj.cmo ::parsing:asttypes.cmi ::bytecomp:bytesections.cmi
::utils:config.cmi ::bytecomp:emitcode.cmi ::typing:ident.cmi
- ::bytecomp:lambda.cmi ::bytecomp:opcodes.cmo opnames.cmo ::utils:tbl.cmi
+ ::bytecomp:instruct.cmi ::bytecomp:lambda.cmi ::bytecomp:opcodes.cmo
+ opnames.cmo ::utils:tbl.cmi
dumpobj.cmx ::parsing:asttypes.cmi ::bytecomp:bytesections.cmx
::utils:config.cmx ::bytecomp:emitcode.cmx ::typing:ident.cmx
- ::bytecomp:lambda.cmx ::bytecomp:opcodes.cmx opnames.cmx ::utils:tbl.cmx
+ ::bytecomp:instruct.cmx ::bytecomp:lambda.cmx ::bytecomp:opcodes.cmx
+ opnames.cmx ::utils:tbl.cmx
objinfo.cmo ::utils:config.cmi ::bytecomp:emitcode.cmi
objinfo.cmx ::utils:config.cmx ::bytecomp:emitcode.cmx
ocamldep.cmo ::utils:clflags.cmo ::parsing:lexer.cmi ::parsing:location.cmi
diff --git a/utils/config.mlp b/utils/config.mlp
index f3ec67407..4d6b9458a 100644
--- a/utils/config.mlp
+++ b/utils/config.mlp
@@ -12,7 +12,7 @@
(* $Id$ *)
-let version = "2.99+15 (2000-04-05)"
+let version = "2.99+16 (2000-04-08)"
let standard_library =
try
diff --git a/yacc/.cvsignore b/yacc/.cvsignore
index 47b05dea2..c27ac6f3c 100644
--- a/yacc/.cvsignore
+++ b/yacc/.cvsignore
@@ -1,2 +1,3 @@
ocamlyacc
*.c.x
+ocamlyacc.xcoff
diff --git a/yacc/Makefile.Mac b/yacc/Makefile.Mac
index fac410d38..290d32c04 100644
--- a/yacc/Makefile.Mac
+++ b/yacc/Makefile.Mac
@@ -15,15 +15,15 @@
# Makefile for the parser generator.
C = sc
-COptions = -includes unix -d NDEBUG -model far -w 2,35
+COptions = -includes unix {cdbgflag} -model far -w 2,35
LinkOptions = -model far -msg nodup -compact -state nouse -br 68k
Libs = "{libraries}IntEnv.far.o" "{libraries}MacRuntime.o"
"{clibraries}StdCLib.far.o" "{libraries}MathLib.far.o"
"{libraries}ToolLibs.o" "{libraries}Interface.o"
PPCC = mrc
-PPCCOptions = -includes unix -d NDEBUG -w 2,35
-PPCLinkOptions = -d
+PPCCOptions = -includes unix {cdbgflag} -w 2,35
+PPCLinkOptions = -d {ldbgflag}
PPCLibs = "{sharedlibraries}MathLib" "{ppclibraries}PPCCRuntime.o"
"{ppclibraries}PPCToolLibs.o" "{sharedlibraries}StdCLib"
"{ppclibraries}StdCRuntime.o" "{sharedlibraries}InterfaceLib"
diff --git a/yacc/closure.c b/yacc/closure.c
index a51126472..f983e23fc 100644
--- a/yacc/closure.c
+++ b/yacc/closure.c
@@ -217,7 +217,7 @@ void print_closure(int n)
void print_EFF(void)
{
- register int i, j, k;
+ register int i, j;
register unsigned *rowp;
register unsigned word;
register unsigned mask;
diff --git a/maccaml/glue.c b/maccaml/glue.c
index 7dcfe672d..8c4f99a11 100644
--- a/maccaml/glue.c
+++ b/maccaml/glue.c
@@ -26,16 +26,13 @@
#include "main.h"
-/* intr_requested is true if the user pressed command-period
- during a read on stdin.
-*/
+/* intr_requested is true if the user pressed command-period and the signal
+ was not sent yet. */
int intr_requested = 0;
/* quit_requested becomes true when the user chooses File:Quit */
int quit_requested = 0;
/* exit_called is true after exit is called. */
int exit_called = 0;
-/* in_gusi is true if we know we are not in a GUSI call-back. */
-int in_gusi = 1;
/* These are defined by the ocamlrun library. */
void caml_main(char **argv);
@@ -98,9 +95,12 @@ pascal void InitCursorCtl (acurHandle newCursors)
static pascal void interp_yield (long counter)
{
- in_gusi = 0;
RotateCursor (counter);
- in_gusi = 1;
+ if (quit_requested) exit (0);
+ if (intr_requested){
+ intr_requested = 0;
+ handle_signal (SIGINT);
+ }
sched_yield ();
}
@@ -300,15 +300,17 @@ static pascal void caml_sio_read (char *buffer, SInt32 nCharsDesired,
for (i = wintopfrontier; i < len; i++){
if (p[i] == '\n') goto gotit;
}
- intr_requested = 0;
- in_gusi = 0;
GetAndProcessEvents (waitEvent, 0, 0);
- in_gusi = 1;
+ if (quit_requested) exit (0);
if (intr_requested){
- *nCharsUsed = 0; /* Hack: behaviour not specified by SIO. */
+ intr_requested = 0;
+ async_signal_mode = 1;
Caml_working (1);
- return;
+ handle_signal (SIGINT);
+ Caml_working (0);
+ async_signal_mode = 0;
}
+ sched_yield ();
}
gotit:
@@ -326,7 +328,8 @@ static pascal void caml_sio_read (char *buffer, SInt32 nCharsDesired,
WEGetSelection (&selstart, &selend, we);
readonly = WEFeatureFlag (weFReadOnly, weBitTest, we);
WEFeatureFlag (weFReadOnly, weBitClear, we);
- /* Always set an empty selection before changing OutlineHilite. */
+ /* Always set an empty selection before changing OutlineHilite or
+ the active status. */
WESetSelection (wintopfrontier, wintopfrontier, we);
WEFeatureFlag (weFOutlineHilite, weBitClear, we);
active = WEIsActive (we);
@@ -398,6 +401,9 @@ pascal void (*__sioWrite) (SInt16, char *, SInt32) = &caml_sio_write;
static pascal void caml_sio_exit (void)
{
+ if (winGraphics != NULL) WinCloseGraphics ();
+ WinCloseToplevel ();
+
exit_called = 1;
if (caml_at_work) Caml_working (0);
if (!quit_requested){
diff --git a/maccaml/graph.c b/maccaml/graph.c
index a23a7bf70..76318bd5b 100644
--- a/maccaml/graph.c
+++ b/maccaml/graph.c
@@ -1109,7 +1109,7 @@ value gr_wait_event (value veventlist)
pt.h = Wx (oldx);
pt.v = Wy (oldy);
LocalToGlobal (&pt);
/* Restore the grafport now because GetAndProcessEvents may longjmp
directly out of here.
*/
PopPort;
@@ -1118,6 +1118,15 @@ value gr_wait_event (value veventlist)
enter_blocking_section ();
Caml_working (0);
GetAndProcessEvents (askmotion ? waitMove : waitEvent, pt.h, pt.v);
+ if (quit_requested) exit (0);
+ if (intr_requested){
+ intr_requested = 0;
+ Caml_working (1);
+ async_signal_mode = 1;
+ handle_signal (SIGINT);
+ async_signal_mode = 0;
+ Caml_working (0);
+ }
Caml_working (1);
leave_blocking_section ();
if (askkey && (evt = GraphQPop ()) != NULL){
@@ -1156,6 +1165,7 @@ value gr_wait_event (value veventlist)
goto gotevent;
}
}
+ sched_yield ();
}
gotevent:
oldx = mouse_x;
@@ -1109,7 +1109,7 @@ value gr_wait_event (value veventlist)
pt.v = Wy (oldy);
LocalToGlobal (&pt);
- /* Restore the grafport now because GetAndProcessEvents may longjmp
+ /* Restore the grafport now because handle_signal may longjmp
directly out of here.
*/